package main

import (
	"fmt"
	"io/ioutil"
	"log"

	"github.com/owulveryck/onnx-go"
	"github.com/owulveryck/onnx-go/backend/x/gorgonnx"
	"gorgonia.org/tensor"
)

func main() {
	// Create a backend receiver
	backend := gorgonnx.NewGraph()
	// Create a model and set the execution backend
	model := onnx.NewModel(backend)

	// read the onnx model
	b, _ := ioutil.ReadFile("test.onnx")
	// Decode it into the model
	err := model.UnmarshalBinary(b)
	if err != nil {
		log.Fatal(err)
	}

	// Set the first input, the number depends of the model
	backing := []float32{2.0}
	input := tensor.New(tensor.WithBacking(backing), tensor.WithShape(1, 1))

	fmt.Printf("%#v\n", input)
	model.SetInput(int(model.Input[0]), input)

	err = backend.Run()
	// Check error
	if err != nil {
		log.Fatal(err)
	}

	output, err := model.GetOutputTensors()
	if err != nil {
		log.Fatal(err)
	}

	// write the output to stdout
	fmt.Printf("%#v\n", output)
}
